==> jc-1.4.0.tar.gz: java/io/BufferedWriter.h <==
// public class java.io.BufferedWriter

// class file dependencies
// @dep_class cf783ee0805571bb java_io_BufferedWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_Writer

#include "java/io/Writer.h"

#ifndef _JC_java_io_BufferedWriter_H_
#define _JC_java_io_BufferedWriter_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_BufferedWriter$sub_refs	_jc_java_io_BufferedWriter$sub_refs;
typedef struct _jc_java_io_BufferedWriter$sub_nonrefs	_jc_java_io_BufferedWriter$sub_nonrefs;
typedef struct _jc_java_io_BufferedWriter$refs	_jc_java_io_BufferedWriter$refs;
typedef struct _jc_java_io_BufferedWriter$nonrefs	_jc_java_io_BufferedWriter$nonrefs;
typedef struct _jc_java_io_BufferedWriter$object	_jc_java_io_BufferedWriter$object;

typedef struct _jc_java_io_BufferedWriter$fields_struct	_jc_java_io_BufferedWriter$fields_struct;
typedef const struct _jc_java_io_BufferedWriter$vmethods	_jc_java_io_BufferedWriter$vmethods;
typedef const struct _jc_java_io_BufferedWriter$vtable	_jc_java_io_BufferedWriter$vtable;
typedef const struct _jc_java_io_BufferedWriter$vtype	_jc_java_io_BufferedWriter$vtype;

// Class fields structure
struct _jc_java_io_BufferedWriter$fields_struct {
	jint	DEFAULT__5fBUFFER__5fSIZE;
};
extern _jc_java_io_BufferedWriter$fields_struct _jc_java_io_BufferedWriter$class_fields;

// Constructors
extern void _jc_java_io_BufferedWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_java_io_Writer$object *);
extern void _jc_java_io_BufferedWriter$method$_init$24a7d218882902a8(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_java_io_Writer$object *, jint);

// Virtual methods
extern void _jc_java_io_BufferedWriter$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_BufferedWriter$object *);
extern void _jc_java_io_BufferedWriter$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_BufferedWriter$object *);
extern void _jc_java_io_BufferedWriter$method$localFlush$40c4d30c1538c20e(_jc_env *, struct _jc_java_io_BufferedWriter$object *);
extern void _jc_java_io_BufferedWriter$method$newLine$12402ae47d296bfc(_jc_env *, struct _jc_java_io_BufferedWriter$object *);
extern void _jc_java_io_BufferedWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_BufferedWriter$object *, jint);
extern void _jc_java_io_BufferedWriter$method$write$4cff879bd9d86786(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_java_lang_String$object *, jint, jint);
extern void _jc_java_io_BufferedWriter$method$write$dc4877c8c0adbc0a(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_char_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_io_BufferedWriter$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_BufferedWriter$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_BufferedWriter$method_info$localFlush$40c4d30c1538c20e;
extern _jc_method _jc_java_io_BufferedWriter$method_info$newLine$12402ae47d296bfc;
extern _jc_method _jc_java_io_BufferedWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_BufferedWriter$method_info$write$4cff879bd9d86786;
extern _jc_method _jc_java_io_BufferedWriter$method_info$write$dc4877c8c0adbc0a;

// Virtual methods structure
struct _jc_java_io_BufferedWriter$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_BufferedWriter$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_BufferedWriter$object *);
	void	(*localFlush$40c4d30c1538c20e)(_jc_env *, struct _jc_java_io_BufferedWriter$object *);
	void	(*newLine$12402ae47d296bfc)(_jc_env *, struct _jc_java_io_BufferedWriter$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_BufferedWriter$object *, jint);
	void	(*write$4cff879bd9d86786)(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_java_lang_String$object *, jint, jint);
	void	(*write$dc4877c8c0adbc0a)(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_char_array *, jint, jint);
};

// Vtable
struct _jc_java_io_BufferedWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_BufferedWriter$vmethods	java_io_BufferedWriter;
};

// Vtype
struct _jc_java_io_BufferedWriter$vtype {
	_jc_type			type;
	_jc_java_io_BufferedWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_BufferedWriter$sub_refs {
	struct _jc_java_io_Writer$object	*out;
	_jc_char_array	*buffer;
};

// Reference instance fields (object)
struct _jc_java_io_BufferedWriter$refs {
    _jc_java_io_BufferedWriter$sub_refs	java_io_BufferedWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_BufferedWriter$sub_nonrefs {
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_BufferedWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_BufferedWriter$sub_nonrefs	java_io_BufferedWriter;
};

// Object instance structure
struct _jc_java_io_BufferedWriter$object {
	_jc_java_io_BufferedWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_BufferedWriter$vtype	*vtype;
	_jc_java_io_BufferedWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_BufferedWriter$vtype _jc_java_io_BufferedWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_BufferedWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_BufferedWriter$class_object;

#endif	/* _JC_java_io_BufferedWriter_H_ */

==> jc-1.4.6.tar.gz: java/io/BufferedWriter.h <==
// public class java.io.BufferedWriter

// class file dependencies
// @dep_class cf783ee0805571bb java_io_BufferedWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_Writer

#include "java/io/Writer.h"

#ifndef _JC_java_io_BufferedWriter_H_
#define _JC_java_io_BufferedWriter_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_BufferedWriter$sub_refs	_jc_java_io_BufferedWriter$sub_refs;
typedef struct _jc_java_io_BufferedWriter$sub_nonrefs	_jc_java_io_BufferedWriter$sub_nonrefs;
typedef struct _jc_java_io_BufferedWriter$refs	_jc_java_io_BufferedWriter$refs;
typedef struct _jc_java_io_BufferedWriter$nonrefs	_jc_java_io_BufferedWriter$nonrefs;
typedef struct _jc_java_io_BufferedWriter$object	_jc_java_io_BufferedWriter$object;

typedef struct _jc_java_io_BufferedWriter$fields_struct	_jc_java_io_BufferedWriter$fields_struct;
typedef const struct _jc_java_io_BufferedWriter$vmethods	_jc_java_io_BufferedWriter$vmethods;
typedef const struct _jc_java_io_BufferedWriter$vtable	_jc_java_io_BufferedWriter$vtable;
typedef const struct _jc_java_io_BufferedWriter$vtype	_jc_java_io_BufferedWriter$vtype;

// Class fields structure
struct _jc_java_io_BufferedWriter$fields_struct {
	jint	DEFAULT__5fBUFFER__5fSIZE;
};
extern _jc_java_io_BufferedWriter$fields_struct _jc_java_io_BufferedWriter$class_fields;

// Constructors
extern void _jc_java_io_BufferedWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_java_io_Writer$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedWriter$method$_init$24a7d218882902a8(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_java_io_Writer$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_BufferedWriter$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_BufferedWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedWriter$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_BufferedWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedWriter$method$localFlush$40c4d30c1538c20e(_jc_env *, struct _jc_java_io_BufferedWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedWriter$method$newLine$12402ae47d296bfc(_jc_env *, struct _jc_java_io_BufferedWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_BufferedWriter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedWriter$method$write$4cff879bd9d86786(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_BufferedWriter$method$write$dc4877c8c0adbc0a(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_BufferedWriter$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_BufferedWriter$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_BufferedWriter$method_info$localFlush$40c4d30c1538c20e;
extern _jc_method _jc_java_io_BufferedWriter$method_info$newLine$12402ae47d296bfc;
extern _jc_method _jc_java_io_BufferedWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_BufferedWriter$method_info$write$4cff879bd9d86786;
extern _jc_method _jc_java_io_BufferedWriter$method_info$write$dc4877c8c0adbc0a;

// Virtual methods structure
struct _jc_java_io_BufferedWriter$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_BufferedWriter$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_BufferedWriter$object *) _JC_JCNI_ATTR;
	void	(*localFlush$40c4d30c1538c20e)(_jc_env *, struct _jc_java_io_BufferedWriter$object *) _JC_JCNI_ATTR;
	void	(*newLine$12402ae47d296bfc)(_jc_env *, struct _jc_java_io_BufferedWriter$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_BufferedWriter$object *, jint) _JC_JCNI_ATTR;
	void	(*write$4cff879bd9d86786)(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*write$dc4877c8c0adbc0a)(_jc_env *, struct _jc_java_io_BufferedWriter$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_BufferedWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_BufferedWriter$vmethods	java_io_BufferedWriter;
};

// Vtype
struct _jc_java_io_BufferedWriter$vtype {
	_jc_type			type;
	_jc_java_io_BufferedWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_BufferedWriter$sub_refs {
	struct _jc_java_io_Writer$object	*out;
	_jc_char_array	*buffer;
};

// Reference instance fields (object)
struct _jc_java_io_BufferedWriter$refs {
    _jc_java_io_BufferedWriter$sub_refs	java_io_BufferedWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_BufferedWriter$sub_nonrefs {
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_BufferedWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_BufferedWriter$sub_nonrefs	java_io_BufferedWriter;
};

// Object instance structure
struct _jc_java_io_BufferedWriter$object {
	_jc_java_io_BufferedWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_BufferedWriter$vtype	*vtype;
	_jc_java_io_BufferedWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_BufferedWriter$vtype _jc_java_io_BufferedWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_BufferedWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_BufferedWriter$class_object;

#endif	/* _JC_java_io_BufferedWriter_H_ */
